package org.opensha2.eq.model;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import org.opensha2.calc.GridCalc;
import org.opensha2.calc.Site;
import org.opensha2.data.DataTable;
import org.opensha2.geo.Location;
import org.opensha2.geo.Locations;
import org.opensha2.util.Parsing;

import com.google.common.base.Joiner;
import com.google.common.base.Predicate;
import com.google.common.primitives.Doubles;

/**
 * This class condenses the point sources that influence hazard at a site
 * to a list of sources with summed rates at evenly spaced distances (or bins).
 * 
 * If optimization is enabled, a GridSourceSet will delegate to a table when iterating
 * sources
 * 
 * These tables are ccreated on a per-calculation basis and are unique to a site.
 *
 * @author Peter Powers
 */
public class GridSourceSetTable {

	/* 
	 * TODO upgrade this to DataVolume to handle azimuth bins??
	 * TODO split over focal mechs? required for UC3 grids
	 */
	
	
	
	final GridSourceSet parent;
	final PointSourceType type;
	final Site site;
	
	List<PointSource> ptSources;
	
	DataTable rateTable;
	
	private GridSourceSetTable(
		GridSourceSet parent,
		PointSourceType type,
		Site site) {
		
		this.parent = parent;
		this.type = type; // TODO source set has this
		this.site = site;
		
		rateTable = toSourceTable(parent, site.location);
	}
		
	
	private int parentSourcesUsed;
	
//	public static void main(String[] args) {
//		double[] dd = new double[] {-1.0000345, 5.67823, 2.5678901e-8};
//		System.out.println(Arrays.toString(dd));
//		System.out.println(Parsing.toString(Doubles.asList(dd), "%s"));
//		String format = "%8.3E";
//		System.out.println(Parsing.toString(Doubles.asList(dd), format, ", ", true));
//		
//		String tmp = "[  180.50] [0.00e+00, 0.00e+00, 0.00e+00, 9.64e-05, 8.01e-05, 6.67e-05, 5.54e-05, 4.61e-05, 3.84e-05, 3.19e-05, 2.65e-05, 2.21e-05, 1.84e-05, 1.53e-05, 1.27e-05, 1.06e-05, 8.79e-06, 7.31e-06, 9.90e-07, 8.24e-07, 6.85e-07, 5.70e-07, 4.74e-07, 0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00]";
//		System.out.println(tmp);
//		tmp.replace("0.00e+00", "zz");
//		System.out.println(tmp);
//	}
	
//	/* To support indenting of multidimensional arrays */
//	private String toString2(double[] data) {
//		StringBuilder sb = new StringBuilder("[");
//		retrParsing.toString(Doubles.asList(data), "%s");
//		String values = Joiner.on(", ").join(data)
//		for (int i = 0; i < data.length; i++) {
//			sb.append(data[i])
////			if (i > 0) sb.append(",").append(NEWLINE).append(repeat(" ", indent));
//			sb.append(Arrays.toString(data[i]));
//		}
//		sb.append("]");
//		return sb.toString();
//	}
	
	
	
//	public static void buildSources(DataTable table) {
//		
//		List<PointSource> ptSources = new ArrayList<>();
//		
//		// for each row in table
//		//		build a point source
//		
//		
//	}
//	
//	
//	public static Iterator<PointSource> iterator() {
//		
//	}

	
	
	public static DataTable toSourceTable(GridSourceSet sources, Location loc) {
		
		System.out.println(sources.mMin);
		System.out.println(sources.mMax);
		System.out.println(sources.Δm);
		System.out.println(sources.mMin - sources.Δm / 2.0);
		
//		DataTable.Builder tableBuilder = GridCalc.createGridBuilder(
//			sources.groundMotionModels().maxDistance());
		
		// table keys are specified as lowermost and uppermost bin edges
		double Δm = sources.Δm;
		double ΔmBy2 = Δm / 2.0;
		double mMin = sources.mMin - ΔmBy2;
		double mMax = sources.mMax + ΔmBy2;
		
		double rMax = sources.groundMotionModels().maxDistance();
		DataTable.Builder tableBuilder = GridCalc.createGridBuilder(rMax, mMin, mMax, Δm);
		
//		System.out.println(rMax);
//		System.out.println(sources.name());
//		System.out.println(Arrays.toString(table.rows()));
//		System.out.println(Arrays.toString(table.columns()));
//		
		
		
		for (PointSource source : sources.iterableForLocation(loc)) {
			double r = Locations.horzDistanceFast(loc, source.loc);
//			double mMin = source.mfd.getMinX();
			List<Double> rates = source.mfd.yValues();
			tableBuilder.add(r, rates);
		}
		
		DataTable table = tableBuilder.build();
		
		return table;
	}
	
	
}
